@@ -2,7 +2,7 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-part of _interceptors;
+part of 'dart:_interceptors';
 
 /// The interceptor class for [String]. The compiler recognizes this
 /// class as an interceptor, and changes references to [:this:] to
