@@ -2,7 +2,7 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-part of dart.async;
+part of "dart:async";
 
 /// Thrown when a deferred library fails to load.
 final class DeferredLoadException implements Exception {
