@@ -2,7 +2,7 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-part of dart.async;
+part of "dart:async";
 
 // -------------------------------------------------------------------
 // Controller for creating and adding events to a stream.
@@ -925,8 +925,9 @@ class _AddStreamState<T> {
   ) : addStreamFuture = _Future(),
       addSubscription = source.listen(
         controller._add,
-        onError:
-            cancelOnError ? makeErrorHandler(controller) : controller._addError,
+        onError: cancelOnError
+            ? makeErrorHandler(controller)
+            : controller._addError,
         onDone: controller._close,
         cancelOnError: cancelOnError,
       );
