@@ -2,7 +2,7 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-part of dart.collection;
+part of "dart:collection";
 
 /// A node in a splay tree. It holds the sorting key and the left
 /// and right children in the tree.
