@@ -2,7 +2,7 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-part of dart.io;
+part of "dart:io";
 
 /// The type of an entity on the file system,
 /// such as a file, directory, or link.
@@ -37,15 +37,14 @@ final class FileSystemEntityType {
   const FileSystemEntityType._internal(this._type);
 
   static FileSystemEntityType _lookup(int type) => _typeList[type];
-  String toString() =>
-      const [
-        'file',
-        'directory',
-        'link',
-        'unixDomainSock',
-        'pipe',
-        'notFound',
-      ][_type];
+  String toString() => const [
+    'file',
+    'directory',
+    'link',
+    'unixDomainSock',
+    'pipe',
+    'notFound',
+  ][_type];
 }
 
 /// The result of calling the POSIX `stat()` function on a file system object.
@@ -183,7 +182,8 @@ interface class FileStat {
     );
   }
 
-  String toString() => """
+  String toString() =>
+      """
 FileStat: type $type
           changed $changed
           modified $modified
@@ -772,7 +772,11 @@ abstract class FileSystemEntity {
   /// [FileSystemEntityType.directory].
   static bool isDirectorySync(String path) =>
       (_getTypeSync(_toUtf8Array(path), true) ==
-          FileSystemEntityType.directory);
+      FileSystemEntityType.directory);
+
+  static bool _isDirectoryIgnoringLinksSync(String path) =>
+      (_getTypeSync(_toUtf8Array(path), false) ==
+      FileSystemEntityType.directory);
 
   external static _getTypeNative(
     _Namespace namespace,
@@ -787,10 +791,9 @@ abstract class FileSystemEntity {
   external static _resolveSymbolicLinks(_Namespace namespace, Uint8List path);
 
   // Finds the next-to-last component when dividing at path separators.
-  static final RegExp _parentRegExp =
-      Platform.isWindows
-          ? new RegExp(r'[^/\\][/\\]+[^/\\]')
-          : new RegExp(r'[^/]/+[^/]');
+  static final RegExp _parentRegExp = Platform.isWindows
+      ? new RegExp(r'[^/\\][/\\]+[^/\\]')
+      : new RegExp(r'[^/]/+[^/]');
 
   /// The parent path of a path.
   ///
@@ -947,6 +950,7 @@ sealed class FileSystemEvent {
   static const int _modifyAttributes = 1 << 4;
   static const int _deleteSelf = 1 << 5;
   static const int _isDir = 1 << 6;
+  static const int _movedTo = 1 << 7;
 
   /// The type of event. See [FileSystemEvent] for a list of events.
   final int type;
