@@ -2,7 +2,7 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-part of dart.io;
+part of "dart:io";
 
 // These match enum StdioHandleType in file.h
 const int _stdioHandleTypeTerminal = 0;
@@ -280,7 +280,7 @@ class Stdout extends _StdSink implements IOSink {
   /// The returned `IOSink` will be initialized with an [encoding] of UTF-8 and
   /// will not do line ending conversion.
   IOSink get nonBlocking {
-    return _nonBlocking ??= new IOSink(new _FileStreamConsumer.fromStdio(_fd));
+    return _nonBlocking ??= new IOSink(new _FileStreamConsumer._fromStdio(_fd));
   }
 }
 
@@ -317,7 +317,7 @@ class StdinException implements IOException {
 class _StdConsumer implements StreamConsumer<List<int>> {
   final RandomAccessFile _file;
 
-  _StdConsumer(int fd) : _file = _File._openStdioSync(fd);
+  _StdConsumer._(int fd) : _file = _File._openStdioSync(fd);
 
   Future addStream(Stream<List<int>> stream) {
     var completer = new Completer();
